@@ -8,7 +8,7 @@ use Carp ();
 use Amon2::Config::Simple;
 use Amon2::ContextGuard;
 
-our $VERSION = '4.03';
+our $VERSION = '4.04';
 {
     our $CONTEXT; # You can localize this variable in your application.
     sub context { $CONTEXT }
@@ -218,7 +218,7 @@ This module makes the context to project local.
 
 It means, normally context class using Amon2 use C<$Amon2::CONTEXT> in each project, but context class using L</PROJECT LOCAL MODE> use C<$MyApp::CONTEXT>.
 
-B<It means you can't use code depend C<<Amon2->context>> and C<<Amon2->context>> under this mode.>
+B<<< It means you can't use code depend C<<Amon2->context>> and C<<Amon2->context>> under this mode. >>>>
 
 =head2 NOTES ABOUT create_request
 
@@ -236,6 +236,12 @@ If you want to use L</PROJECT LOCAL MODE>, you need to pass class name of contex
         Amon2::Web::Request->new($env, $class);
     }
 
+=head2 HOW DO I ENABLE PROJECT LOCAL MODE?
+
+C< MyApp->make_local_context() > turns on the project local mode.
+
+There is no way to revert it, thanks.
+
 =head2 METHODS
 
 This module inserts 3 methods to your context class.
